<?php
/*
Plugin Name: Facebook Venue
Plugin URI: http://rjksn.me/
Description: A plugin that allows displaying of Facebook location information in WordPress.
Author: Ryan Jackson
Version: 0.1
Author URI: http://rjksn.me/
*/

class FB_Venue { 
	public $plugin_url;
	public $venues;

	function __construct() {
		
		$this->plugin_url = plugin_dir_url(__FILE__);
		
		// Add shortcode
		add_shortcode( 'fbvenue', array( $this, 'fb_venue_shortcode') );

		// Add the default styles
		add_action( 'wp_head', array( $this, 'page_css' ) );
	}
	
	public function fb_venue_shortcode( $atts ) {
		extract( shortcode_atts( array(
			'id'	 => '', 
			'detail' => 'name',
			'type'   => 'default'

		), $atts ) );

		
		// if ( !is_numeric( $id ) ) return '';
		$id = esc_attr( $id );
		
		if ( !isset( $this->venues[$id] ) ) {
			$this->fb_load_details( $id );
		}
		
		$possible_details = array( 'name', 'picture', 'link', 'likes', 'category', 'founded', 'mission', 'description', 'about', 'location', 'hours', 'phone', 'checkins', 'talking_about_count' ); 
		if ( isset( $this->venues[ $id ][ $detail ] ) || $detail == 'default' ) {
			
			$elementid	= 'fbvenue-' . $this->venues[ $id ]['id'] . '-' . $detail; 	
			$elementclass = 'fbvenue-' . $detail . ' fbvenue-' . $this->venues[ $id ]['id']; 	


			switch ( $detail ) {
				case 'default':
					$this->fb_create_map( $id ); 

					$output = '<div id="' . $elementid . '">
							<div id="' . str_replace( 'default', 'location', $elementid ) . '" style="width: 60%; height: 400px; float: left;"></div>
								<div class="fbvenue_content" style="padding-left: 2%; margin-left: 2%; width: 35%; border-left: 1px solid #ccc; float: left;">
									<h2>' . ( $this->venues[ $id ]['name'] ?  $this->venues[ $id ]['name'] : get_bloginfo('name') ) . '</h2>' . 
									( $this->venues[ $id ]['about'] ? '<p>' . $this->venues[ $id ]['about'] . '</p>' : '' ) .
									
									( $this->venues[ $id ]['location'] ? '<h3>Location</h3><p>' . $this->venues[ $id ]['location']['street'] . '<br/>' . $this->venues[ $id ]['location']['city'] . ', ' . $this->venues[ $id ]['location']['state'] . '<br/>' . $this->venues[ $id ]['location']['country'] . ', ' . $this->venues[ $id ]['location']['zip'] . '</p>' : '' ) .

									( $this->venues[ $id ]['phone'] ? '<h3>Contact</h3><p><a href="mailto:' . get_settings('admin_email') . '">' . get_settings('admin_email') . '</a><br/>' . $this->formatPhone( $this->venues[ $id ]['phone'] ) . '</p>' : '' ) .
						
					'</div><br style="clear: both;" />';

					break;
				case 'picture':
					$output = '<img id="' . $elementid . '" class="'. $elementclass . '" src="' . $this->venues[ $id ][ $detail ] . '" alt="' . $this->venues[ $id ]['name'] . '" />';
					break;
				case 'location':
					$this->fb_create_map( $id ); 
						
					$output = '<div id="' . $elementid . '" style="width: 100%; height: 400px;"></div>';
					break;
					
				case 'hours':
					$output = '<!-- Coming soon -->';
					break;
				default: 
					$output = '<span id="' . $elementid . '" class="'. $elementclass . '">' . $this->venues[ $id ][ $detail ] . '</span>';
			}
		} else { 
			$output = '<!-- There was a problem getting the details -->';
		}

		return $output;
	}
	
	private function fb_load_details( $id ) {


		$curl = curl_init();
			curl_setopt ($curl, CURLOPT_URL, 'https://graph.facebook.com/' . $id );
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
			$page_details_raw = curl_exec ($curl);
		curl_close ($curl);

		$page_details = json_decode($page_details_raw, true);
		
		$this->venues[ $id ] = $page_details;
		
		return true;
	}
	
	private function formatPhone($num) {
		$num = preg_replace('/[^0-9]/', '', $num);
		 
		$len = strlen($num);
		if($len == 7)
		$num = preg_replace('/([0-9]{3})([0-9]{4})/', '$1-$2', $num);
		elseif($len == 10)
		$num = preg_replace('/([0-9]{3})([0-9]{3})([0-9]{4})/', '($1) $2-$3', $num);
		 
		return $num;
	}
	
/* 
 * Display Map through shortcode
 * 
*/
	private function fb_create_map( $id ) { 
	
		$elementid	= 'fbvenue-' . $this->venues[ $id ]['id'] . '-location'; 	
		$venue_lat  = $this->venues[ $id ]['location']['latitude'];
		$venue_lon  = $this->venues[ $id ]['location']['longitude'];
		?>
		
		<script type="text/javascript" src="https://maps.googleapis.com/maps/api/js?sensor=false"></script>
		<script type="text/javascript" src="<?php echo $this->plugin_url ?>js/infobox.js"></script>
		<script type="text/javascript">
			var map;
			var venuelocation = new google.maps.LatLng( <?php echo $venue_lat; ?>, <?php echo $venue_lon; ?>);
      
      
			function getbox() { 
				
				div = document.createElement("div");
				
				div.style.border      = "1px solid #aaa";
				div.style.padding     = "7px";
				div.style.position    = "absolute";
				div.style.background  = "#fff";
				div.style.width       = "225px";
				div.style.height      = "62px";
				
				var profileimage_div = document.createElement("div")
				profileimage_div.style.cssText      = "width: 60px; height: 60px; overflow: hidden; float: left; border: 1px solid #999";
				
				var profileimage_img = document.createElement("img")
				profileimage_img.style.cssText   = "width: 60px; height: 60px;";
				profileimage_img.src = "<?php echo $this->venues[ $id ]['picture']; ?>";
				
				profileimage_div.appendChild(profileimage_img);
				
				var contentDiv = document.createElement("div");
				contentDiv.style.cssText      = "display: block; float: right; position: absolute; width: 155px; left: 77px; top: 10px; line-height: 1.25; color: #999";
				
				contentDiv.innerHTML = "<b style=\"font-weight: bold; color: #444;\"><?php echo $this->venues[ $id ]['name']; ?></b><br><?php echo $this->venues[ $id ]['location']['street']; ?> <br> <?php echo $this->venues[ $id ]['location']['city']; ?>, <?php echo $this->venues[ $id ]['location']['state']; ?>, <?php echo $this->venues[ $id ]['location']['country']; ?>";
				
				
				var bottomArrow = document.createElement("div")
				bottomArrow.style.cssText        = "width: 75px; height: 11px; position: absolute; bottom: -11px; left: 0; background-image: url(<?php echo $this->plugin_url; ?>/images/fb-venue-map-arrow.png);";
				
				div.appendChild(profileimage_div);
				div.appendChild(contentDiv);
				div.appendChild(bottomArrow);
				
				return div;
			}

			function initialize() {
				var myOptions = {
				zoom: 8,
				center: new google.maps.LatLng(<?php echo round( $venue_lat , 3 ); ?>, <?php echo round( $venue_lon, 3 ); ?>),
				mapTypeId: google.maps.MapTypeId.ROADMAP
				};
				
				map = new google.maps.Map(document.getElementById('<?php echo $elementid; ?>'), myOptions);

				var myOptions = {
					content: getbox(),
					pixelOffset: new google.maps.Size(-39, -88),
					position: venuelocation,

					disableAutoPan: false,
					maxWidth: 0,

					zIndex: null,
					boxStyle: {
						opacity: 0.9,
					},
					closeBoxMargin: "10px 2px 2px 2px",
					closeBoxURL: "http://www.google.com/intl/en_us/mapfiles/close.gif",
					infoBoxClearance: new google.maps.Size(1, 1),
					isHidden: false,
					pane: "floatPane",
					enableEventPropagation: false
				};

				var ib = new InfoBox(myOptions);
				ib.open(map);
        
			}
			google.maps.event.addDomListener(window, 'load', initialize);

		</script>
	<?php }
	
	public function page_css() {
		echo "";
	}
} 
$fbvenue = new FB_Venue;
